@@ -170,10 +170,10 @@ find_available_versions <- function(package, repos = getOption('repos'), type =
 
   archive <- read_archive_rds(repos)
   if (length(archive) != 0) {
+    archiveurl <- contrib.url(repos, 'source')
     package_tarball_path <- row.names(archive[[package]])
-    archive_versions <- data.frame(version = sub(switch(type,
-            source = ".*_(.*).tar.gz", mac.binary = ".*_(.*).tgz", win.binary = ".*_(.*).zip"), '\\1', package_tarball_path), source='archive', stringsAsFactors=FALSE)
-    archive_versions$url <- file.path(contriburl, 'Archive', package_tarball_path)
+    archive_versions <- data.frame(version = sub(".*_(.*).tar.gz", '\\1', package_tarball_path), source='archive', stringsAsFactors=FALSE)
+    archive_versions$url <- file.path(archiveurl, 'Archive', package_tarball_path)
 
     versions <- merge(root_versions, archive_versions, all=TRUE)
   } else {
